.. _all-salt.modules:

======================================
Full list of builtin execution modules
======================================

.. admonition:: Virtual modules

    .. toctree::

        salt.modules.pkg
        salt.modules.sys

.. currentmodule:: salt.modules

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    aliases
    alternatives
    apache
    apt
    archive
    at
    augeas_cfg
    bluez
    brew
    bridge
    bsd_shadow
    cassandra
    cmdmod
    config
    cp
    cron
    daemontools
    darwin_sysctl
    data
    debconfmod
    debian_service
    dig
    disk
    djangomod
    dnsmasq
    dnsutil
    dpkg
    ebuild
    eix
    eselect
    event
    extfs
    file
    freebsdjail
    freebsdkmod
    freebsdpkg
    freebsdservice
    freebsd_sysctl
    gem
    gentoolkitmod
    gentoo_service
    git
    glance
    grains
    groupadd
    grub_legacy
    guestfs
    hg
    hosts
    img
    iptables
    keyboard
    key
    keystone
    kmod
    launchctl
    layman
    ldapmod
    linux_acl
    linux_lvm
    linux_sysctl
    localemod
    locate
    logrotate
    makeconf
    match
    mdadm
    mine
    mongodb
    monit
    moosefs
    mount
    munin
    mysql
    netbsdservice
    netbsd_sysctl
    network
    nfs3
    nginx
    nova
    npm
    nzbget
    openbsdpkg
    openbsdservice
    osxdesktop
    pacman
    pam
    parted
    pecl
    pillar
    pip
    pkgin
    pkgng
    pkg_resource
    pkgutil
    portage_config
    postgres
    poudriere
    ps
    publish
    puppet
    pw_group
    pw_user
    qemu_img
    qemu_nbd
    quota
    rabbitmq
    rbenv
    reg
    ret
    rh_ip
    rh_service
    rpm
    rvm
    s3
    saltutil
    selinux
    service
    shadow
    smartos_imgadm
    smartos_vmadm
    smf
    solaris_group
    solarispkg
    solaris_shadow
    solaris_user
    solr
    sqlite3
    ssh
    state
    status
    supervisord
    svn
    sysbench
    sysmod
    systemd
    system
    test
    timezone
    tls
    tomcat
    upstart
    useradd
    virt
    virtualenv
    win_disk
    win_file
    win_groupadd
    win_network
    win_pkg
    win_service
    win_shadow
    win_status
    win_system
    win_useradd
    xapi
    yumpkg5
    yumpkg
    zfs
    zpool
    zypper
